========
Examples
========

This page contains a collection of documented examples and notebooks that
demonstrate how Coiled can be used for a variety of use cases.

.. tip::
    
    To run the examples below, you'll need your local and Coiled software environments
    to be in sync. Coiled maintains `software environments for each of these examples <https://cloud.coiled.io/examples/software>`_,
    which can be installed locally using the ``coiled install`` command line tool
    (see the documentation on :doc:`software_environment_local` for more details).

.. toctree::
   :maxdepth: 1
   :hidden:

   examples/snowflake
   examples/mongodb
   examples/prefect
   examples/streamlit
   examples/optuna

- `Coiled Quickstart <https://github.com/coiled/notebooks/blob/main/quickstart/quickstart.ipynb>`_
- `Using Coiled with JupyterLab <https://github.com/coiled/notebooks/blob/main/jupyterlab/jupyterlab.ipynb>`_
- :doc:`Connecting to Snowflake from Coiled <examples/snowflake>`
- :doc:`Connecting to MongoDB from Coiled <examples/mongodb>`
- :doc:`Workflow automation with Prefect and Coiled <examples/prefect>`
- :doc:`Web applications with Streamlit and Coiled <examples/streamlit>`
- :doc:`Hyperparameter optimization with Optuna and Coiled <examples/optuna>`
- `Scaling XGBoost with Dask and Coiled <https://github.com/coiled/notebooks/blob/main/scaling-xgboost/scaling-xgboost.ipynb>`_
- `Tune a PyTorch model with Hyperband cross-validation <https://github.com/coiled/notebooks/blob/main/hyperband/hyperband-optimization.ipynb>`_
- `Analyzing data with Dask-SQL <https://github.com/coiled/notebooks/blob/main/dask-sql/dask-sql.ipynb>`_
